@@ -5,6 +5,7 @@ from ..utils import (
     ExtractorError,
     str_or_none,
     traverse_obj,
+    update_url,
 )
 
 
@@ -17,14 +18,14 @@ class PicartoIE(InfoExtractor):
             'ext': 'mp4',
             'title': 're:^Setz [0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}$',
             'timestamp': int,
-            'is_live': True
+            'is_live': True,
         },
         'skip': 'Stream is offline',
     }
 
     @classmethod
     def suitable(cls, url):
-        return False if PicartoVodIE.suitable(url) else super(PicartoIE, cls).suitable(url)
+        return False if PicartoVodIE.suitable(url) else super().suitable(url)
 
     def _real_extract(self, url):
         channel_id = self._match_id(url)
@@ -42,16 +43,17 @@ class PicartoIE(InfoExtractor):
   getLoadBalancerUrl(channel_name: "%s") {
     url
   }
-}''' % (channel_id, channel_id),
-            })['data']
+}''' % (channel_id, channel_id),  # noqa: UP031
+            }, headers={'Accept': '*/*', 'Content-Type': 'application/json'})['data']
         metadata = data['channel']
 
         if metadata.get('online') == 0:
             raise ExtractorError('Stream is offline', expected=True)
         title = metadata['title']
 
-        cdn_data = self._download_json(
-            data['getLoadBalancerUrl']['url'] + '/stream/json_' + metadata['stream_name'] + '.js',
+        cdn_data = self._download_json(''.join((
+            update_url(data['getLoadBalancerUrl']['url'], scheme='https'),
+            '/stream/json_', metadata['stream_name'], '.js')),
             channel_id, 'Downloading load balancing info')
 
         formats = []
@@ -80,7 +82,7 @@ class PicartoIE(InfoExtractor):
             'is_live': True,
             'channel': channel_id,
             'channel_id': metadata.get('id'),
-            'channel_url': 'https://picarto.tv/%s' % channel_id,
+            'channel_url': f'https://picarto.tv/{channel_id}',
             'age_limit': age_limit,
             'formats': formats,
         }
@@ -95,20 +97,20 @@ class PicartoVodIE(InfoExtractor):
             'id': 'ArtofZod_2017.12.12.00.13.23.flv',
             'ext': 'mp4',
             'title': 'ArtofZod_2017.12.12.00.13.23.flv',
-            'thumbnail': r're:^https?://.*\.jpg'
+            'thumbnail': r're:^https?://.*\.jpg',
         },
         'skip': 'The VOD does not exist',
     }, {
-        'url': 'https://picarto.tv/ArtofZod/videos/772650',
-        'md5': '00067a0889f1f6869cc512e3e79c521b',
+        'url': 'https://picarto.tv/ArtofZod/videos/771008',
+        'md5': 'abef5322f2700d967720c4c6754b2a34',
         'info_dict': {
-            'id': '772650',
+            'id': '771008',
             'ext': 'mp4',
             'title': 'Art of Zod - Drawing and Painting',
             'thumbnail': r're:^https?://.*\.jpg',
             'channel': 'ArtofZod',
             'age_limit': 18,
-        }
+        },
     }, {
         'url': 'https://picarto.tv/videopopout/Plague',
         'only_matching': True,
@@ -130,8 +132,8 @@ class PicartoVodIE(InfoExtractor):
       name
     }}
   }}
-}}'''
-            })['data']['video']
+}}''',
+            }, headers={'Accept': '*/*', 'Content-Type': 'application/json'})['data']['video']
 
         file_name = data['file_name']
         netloc = urllib.parse.urlparse(data['video_recording_image_url']).netloc
